@@ -45,7 +45,12 @@ Puppet::Type.newtype(:trove_api_paste_ini) do
     defaultto('<SERVICE DEFAULT>')
   end
 
-  autorequire(:package) do
-    'trove-api'
+  newparam(:key_val_separator) do
+    desc 'The separator string to use between each setting name and value.'
+    defaultto('=')
+  end
+
+  autorequire(:anchor) do
+    ['trove::install::end']
   end
 end
